#!/usr/local/bin/perl -w

use strict;
use warnings;

use CGI;
my $q = new CGI;
use CGI::Cookie;
use URI::Escape;

use Fcntl qw(:flock);

use Phoneme;
use Constraints;
use Link;
use MakeHTML;





# read cookies
my %cookies = fetch CGI::Cookie;

# sets phonetic alphabet
my $alphabet = $cookies{alphabet} || "";
$alphabet = ($alphabet =~ /^alphabet=([^;]*);/)[0] || "";
$alphabet = "APAU" unless ($alphabet =~ /^[IA]PA[U]?$/);
sub unicode { return (index($alphabet,"U")!=-1) ? "U" : ""; }
setAlphabet($alphabet);

# set CON
my $CON = $cookies{CON} || "";
$CON = uri_unescape(($CON =~ /^CON=([^;]*);/)[0]) || "";
my $CONSeparator = "<SPAN STYLE='font-size:1px;'> </SPAN><SPAN CLASS='CONsep'><SPAN STYLE='position:relative;left:3px;'>></SPAN><SPAN STYLE='position:relative;left:-3px;'>></SPAN></SPAN>";


#set inputs
my $inputs = $cookies{inputs} || "";
$inputs = uri_unescape(($inputs =~ /^inputs=([^;]*);/)[0]) || "";

#read user email
my $currUserEmail = $cookies{userEmail} || "";
$currUserEmail = uri_unescape(($currUserEmail =~ /^userEmail=([^;]*);/)[0]) || "";


#read CONs on file
my @publicCONs;
my @privateCONs;
my $scriptStr;
my $fileErrorMsg;

open (CONS, "<data/CONs.txt") or $fileErrorMsg = "Can't read posted rankings, file missing.";
flock(CONS, LOCK_SH);
while (<CONS>) {

	my $CONid           = (/^id=([^;]*);/)[0]          || "";
	my $public          = (/;public=([^;]*);/)[0]      || "";
	my $userEmail       = (/;email=([^;]*);/)[0]       || "";
	my $userName        = (/;name=([^;]*);/)[0]        || "";
	my $userAffiliation = (/;affiliation=([^;]*);/)[0] || "";
	my $CON             = (/;CON=([^;]*);/)[0]         || "";
	my $inputs          = (/;inputs=([^;]*);/)[0]      || "";
	my $comment         = (/;comment=([^;]*);/)[0]     || "";

	if (($public==1) or($public==0 and $userEmail eq $currUserEmail)) {

		$scriptStr .= "		" if ($scriptStr);
		$scriptStr .= "info[$CONid] = \"CON=$CON;inputs=$inputs\";\n";
		my @currCON = split(/,/,$CON);
		for (@currCON) {
			if (exists ${CON()}{$_}) {
				$_ = ${CON()}{$_}->();
			} else {
				die "The constraint named '$_' caused an error. $!"
			}
		}
		my $showCON = join($CONSeparator, @currCON);
	
		my $temp = [$CONid,$userEmail,$userName,$userAffiliation,$showCON,$inputs,$comment];
		if ($public) {
			push(@publicCONs,$temp);
		} else {
			push(@privateCONs,$temp);
		}
	}

}
close(CONS);


# read nav bar
my $navStr;
open (NAV, "<navbar.txt") or die "Can't read navbar. $!";
$navStr .= $_ while (<NAV>);
close(NAV);

my $menuStr;
open (NAV, "<ranking_menu.txt") or die "Can't read ranking menu. $!";
while (<NAV>) {
    $menuStr .= $_;
}
close(NAV);


# create the body of the page
print $q->header;
print <<"EOF";
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<HTML xmlns="http://www.w3.org/1999/xhtml" lang="en-US" xml:lang="en-US">
<HEAD>
	<TITLE>CCamelOT - An OT-CC implementation</TITLE>
	
	<LINK rel="stylesheet" type="text/css" href="mich.css" />
	<META http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	
	<SCRIPT src="toolbox.js" type="text/javascript"></SCRIPT>
	<SCRIPT type="text/javascript">
		//<![CDATA[
		
		var info = [];
		$scriptStr
		
		function setInfo(infoIndex) {
			var temp = info[infoIndex];
			var CON = temp.substring(temp.indexOf("CON=")+4,temp.indexOf(";"));
			document.cookie = "CON=" + CON;

			temp = temp.substring(temp.indexOf(";")+1, temp.length);
			var inputs = temp.substring(temp.indexOf("inputs=")+7,temp.length);
			if (inputs) document.cookie = "inputs=" + inputs;

			location.href = "tableau.cgi";
		}
		
		function confirmDeletion() {
			return confirm("Are you sure you want to delete this ranking? Deleted rankings can't be restored.");
		}
		
		function init() {
			document.getElementById("ranking_tab").className = "navOn";
			document.getElementById("openTab").className = "menuOn" ;
		}
		
		//]]>
	</SCRIPT>
</HEAD>

<BODY LEFTMARGIN=0 TOPMARGIN=0 MARGINWIDTH=0 MARGINHEIGHT=0 onLoad="init()">

$navStr

$menuStr

<DIV CLASS="menuMain">
EOF

print "<DIV CLASS=errorMsg>" , $fileErrorMsg , "</DIV><BR>" if ($fileErrorMsg);

print "\t<DIV CLASS=title>Private rankings</DIV>\n";
if (@privateCONs) {
	print "\t<OL>\n";
	for (@privateCONs) {

		print "\t\t<LI>\n";
		print "\t\t", ${$_}[4], "<BR><BR>\n";
		print "\t\t<DIV STYLE='font-size:150%;line-size:150%'>" , MakeHTML::candHTML(Link->new(split(/:/,${$_}[5])),1) , "</DIV><BR>\n" if (${$_}[5]);
		print "\t\t${$_}[6]<BR><BR>\n" if (${$_}[6]);
		print "\t\t<DIV STYLE='font-size:80%'><A HREF='javascript:setInfo(${$_}[0]);'>Open</A> &nbsp; <A HREF='delete.cgi?CONid=${$_}[0]' onClick='return confirmDeletion()'>Delete</A></DIV>\n";
		print "\t\t<HR WIDTH='80%' ALIGN='left' STYLE='height:1px;margin-top:20px;margin-bottom:20px;'>\n";
		print "\t\t</LI>\n\n";
		
	}
	print "\t</OL>\n\n";
} else {
	if ($currUserEmail eq "") {
		print "No user is currently logged in. <A HREF='login.cgi'>Log in</A> to see your private rankings.<BR><BR>";
	} else {
		print "\tNo private rankings were found.<BR><BR>\n\n";
	}
}


print "\t<DIV CLASS=title>Public rankings</DIV>\n";
if (@publicCONs) {
	print "\t<OL>\n";
	for (@publicCONs) {
		print "\t\t<LI>\n";
		print "\t\t" , ${$_}[4], "<BR><BR>\n";
		print "\t\t<DIV STYLE='font-size:150%;line-size:150%'>" , MakeHTML::candHTML(Link->new(split(/:/,${$_}[5])),1) , "</DIV><BR>\n" if (${$_}[5]);
		print "\t\t${$_}[6]<BR><BR>\n" if (${$_}[6]);
		print "\t\t<DIV STYLE='font-size:80%;'>\n\t\t\tPosted by \n";
		
			my $link = '<A HREF="mailto:' . ${$_}[1] . '">' . ${$_}[2] . '</A>';
			my $obfuscatedEmail = "\t\t\t<SCRIPT type='text/javascript' language='javascript'>\n\t\t\t//<![CDATA[\n\t\t\t	document.write(String.fromCharCode(";
			   for (my $i=0; $i<length($link); $i++) {
				$obfuscatedEmail .= ord(substr($link,$i,1));
				$obfuscatedEmail .= ($i<(length($link)-1)) ? "," : ")";
			}
			$obfuscatedEmail .= ");\n\t\t\t	document.close();\n\t\t\t//]]>\n\t\t\t</SCRIPT>\n";

			print "$obfuscatedEmail ";
			print "\t\t\tof ${$_}[3]" if (${$_}[3]);
			print "<BR>\n";
			print "\t\t\t<A HREF='javascript:setInfo(${$_}[0]);'>Open</A>";

			if ($currUserEmail eq ${$_}[1]) {
				print " &nbsp; <A HREF='delete.cgi?CONid=${$_}[0]' onClick='return confirmDeletion()'>Delete</A>\n";
			}
		
		print "\t\t</DIV>\n";
		print "\t\t<HR WIDTH='80%' ALIGN='left' STYLE='height:1px;margin-top:20px;margin-bottom:20px;'>\n";
		print "\t\t</LI>\n\n";
	}
	print "\t</OL>\n";
}

print "</DIV>\n\n";

# read footer
open (FTR, "<footer.txt") or die "Can't read footer. $!";
print while (<FTR>);
close(FTR);

print <<"EOF";

</BODY>
</HTML>

EOF
