#!/usr/local/bin/perl -w

use strict;
use warnings;

use CGI;
my $q = new CGI;
use CGI::Cookie;
use URI::Escape;

use Fcntl qw(:flock);

use Phoneme;
use Constraints;
use Link;
use Chain;
use MakeHTML;



# read cookies
my %cookies = fetch CGI::Cookie;

# sets phonetic alphabet
my $alphabet = $cookies{alphabet} || "";
$alphabet = ($alphabet =~ /^alphabet=([^;]*);/)[0] || "";
$alphabet = "APAU" unless ($alphabet =~ /^[IA]PA[U]?$/);
sub unicode { return (index($alphabet,"U")!=-1) ? "U" : ""; }
setAlphabet($alphabet);

# set CON
my $CON = uri_unescape(($cookies{CON} =~ /^CON=([^;]*);/)[0]) || "";

#set inputs
my $inputs = uri_unescape(($cookies{inputs} =~ /^inputs=([^;]*);/)[0]) || "";


# stop if there is not matching sub for all constraints
for (split(/,/,$CON)) {
	die "The constraint named '$_' caused an error. $!" unless exists ${CON()}{$_};
}


# creates an array of Links from the input and needed HTML
my @inputs = split(/;/,$inputs);
#for (my $i=0 ; $i<@inputs; $i++) {
	$inputs[0] = Link->new(split(/:/,$inputs[0]));
#}





# create the beginning of the page
print $q->header;
print <<"EOF";
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<HTML xmlns="http://www.w3.org/1999/xhtml" lang="en-US" xml:lang="en-US">
<HEAD>
	<TITLE>CCamelOT - An OT-CC implementation</TITLE>
	
	<LINK rel="stylesheet" type="text/css" href="mich.css" />
	<META http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<META http-equiv="Pragma" content="no-cache" />
	
	<SCRIPT src="toolbox.js" type="text/javascript"></SCRIPT>
	<SCRIPT>
		function toggleView(elem) {
			if (document.getElementById) {
				document.getElementById(elem).style.display = (document.getElementById(elem).style.display == "block") ? "none" : "block";
			}
		}
		
		function init() {
			document.getElementById("tableau_tab").className = "navOn";
			initDisplay();
		}
	</SCRIPT>
</HEAD>

<BODY LEFTMARGIN=0 TOPMARGIN=0 MARGINWIDTH=0 MARGINHEIGHT=0 onLoad="init()">

EOF

# create HTML for nav bar
open (NAV, "<navbar.txt") or die "Can't read navbar. $!";
print while (<NAV>);
close(NAV);


if ($CON eq "") {
	print "<DIV CLASS='pagebody'><DIV CLASS='errorMsg'>No constraint ranking was supplied for the derivation.<BR><A HREF='CONs.cgi'>Open</A> an existing ranking or creat a <A HREF='CONEditor.cgi'>new</A> one.</DIV></DIV>";
} else {

	if ($inputs eq "") {
		print "<DIV CLASS='pagebody'><DIV CLASS='errorMsg'>No input was supplied for the derivation.<BR><A HREF='inputs.cgi'>Choose</A> an input or <A HREF='inputEditor.cgi'>create</A> one and try again.</DIV></DIV>";
	} else {
		my $debug = "";
		$debug = "1" if  ($q->param("keywords") eq "debug");
		MakeHTML::drawTableau($inputs[0],$CON,$debug) ;
	
		if ($inputs eq "::") {
			print "<DIV CLASS='pagebody'>This derivation used a segmentless input. If that was your intention, that's fine.<BR> Otherwise, <A HREF='inputEditor.cgi'>add segments</A> to your input.</DIV>";
		}
	}
}

print <<"EOF";


<FORM NAME="display">
<DIV ID="display">
	Display:
	<INPUT TYPE="checkbox" NAME="segIndex" onClick="updateCookie(this.name,this.checked);"> Segment indices
	<INPUT TYPE="checkbox" NAME="lums"     onClick="updateCookie(this.name,this.checked);"> LUMseq
	<INPUT TYPE="checkbox" NAME="rlumseq"  onClick="updateCookie(this.name,this.checked);"> rLUMseq
	<INPUT TYPE="checkbox" NAME="links"    onClick="updateCookie(this.name,this.checked);"> Non-final links
</DIV>
</FORM>
EOF


# read footer
open (FTR, "<footer.txt") or die "Can't read footer. $!";
print while (<FTR>);
close(FTR);

print "</BODY>\n</HTML>\n";
